@@ -12,7 +12,8 @@ A model that can autonomously use wisent-guard capabilities on itself:
 import asyncio
 from typing import Any, Dict, List, Optional
 
-from wisent.core.activations import ActivationAggregationStrategy, Activations
+from wisent.core.activations.core.atoms import ActivationAggregationStrategy
+from wisent.core.activations.activations import Activations
 
 from .agent.diagnose import AgentClassifierDecisionSystem, AnalysisResult, ClassifierMarketplace, ResponseDiagnostics
 from .agent.steer import ImprovementResult, ResponseSteering
@@ -768,9 +769,16 @@ class AutonomousAgent:
             if not classifier_config:
                 return None
 
+            # Validate required classifier configuration
+            if "layer" not in classifier_config:
+                raise ValueError(
+                    "Classifier configuration must include 'layer' parameter. "
+                    "Please ensure your classifier configuration file specifies the optimal layer."
+                )
+
             # Create ClassifierParams from stored data
             params = ClassifierParams(
-                optimal_layer=classifier_config.get("layer", 15),
+                optimal_layer=classifier_config["layer"],
                 classification_threshold=classifier_config.get("threshold", 0.5),
                 training_samples=classifier_config.get("samples", 25),
                 classifier_type=classifier_config.get("type", "logistic"),
