@@ -284,9 +284,17 @@ class WisentModel:
             {"input_ids": tensor([[...]]), "attention_mask": tensor([[...]])}
         """
 
-        ids = self.tokenizer.apply_chat_template(
-            message, tokenize=True, add_generation_prompt=add_generation_prompt, enable_thinking=enable_thinking, return_tensors="pt"
-        )[0]
+        try:
+            ids = self.tokenizer.apply_chat_template(
+                message, tokenize=True, add_generation_prompt=add_generation_prompt, enable_thinking=enable_thinking, return_tensors="pt"
+            )[0]
+        except ValueError as e:
+            if "chat_template is not set" in str(e):
+                # Fallback for models without chat templates: concatenate messages
+                text = " ".join([msg.get("content", "") for msg in message if isinstance(msg, dict)])
+                ids = self.tokenizer.encode(text, return_tensors="pt")[0]
+            else:
+                raise
         return {
             "input_ids": ids,
             "attention_mask": torch.ones_like(ids),
@@ -334,6 +342,36 @@ class WisentModel:
 
         return batch
 
+    def _extract_assistant_response(self, text: str) -> str:
+        """
+        Extract only the assistant's response from a decoded chat template output.
+
+        When using chat templates, tokenizer.batch_decode returns the full formatted
+        text including system prompt, user prompt, and assistant response. This method
+        extracts only the assistant's response portion.
+
+        arguments:
+            text:
+                Full decoded text from tokenizer.batch_decode
+
+        returns:
+            Extracted assistant response text
+
+        example:
+            >>> full_text = "system\\n\\nCutting Knowledge Date: December 2023\\nToday Date: 02 Nov 2025\\n\\nuser\\n\\nHello\\nassistant\\n\\nHi there!"
+            >>> model._extract_assistant_response(full_text)
+            "Hi there!"
+        """
+        # Look for the assistant marker in the decoded text
+        if "assistant" in text:
+            # Split on "assistant" and take everything after it
+            response = text.split("assistant", 1)[1]
+            # Strip leading/trailing whitespace and newlines
+            response = response.strip()
+            return response
+        # If no assistant marker found, return the original text
+        return text
+
     @torch.inference_mode()
     def generate(
         self,
@@ -341,12 +379,17 @@ class WisentModel:
         max_new_tokens: int = 128,
         temperature: float = 0.7,
         top_p: float = 0.95,
+        top_k: int = 50,
+        repetition_penalty: float = 1.12,
+        no_repeat_ngram_size: int = 4,
         do_sample: bool = True,
         num_return_sequences: int = 1,
         use_steering: bool = False,
         steering_plan: SteeringPlan | None = None,
         enable_thinking: bool = True,
         prompt_is_formatted: bool = False,
+        ensure_varied_responses: bool = False,
+        phrase_ledger: Any = None,
         **gen_kwargs: Any,
     ) -> list[str]:
         """
@@ -470,11 +513,15 @@ class WisentModel:
             # Current behavior: apply chat template
             batch = self._batch_encode(inputs, add_generation_prompt=True, enable_thinking=enable_thinking)
 
-        gen_out = self.hf_model.generate(
+        # Build generation kwargs
+        generation_kwargs = dict(
             **batch,
             max_new_tokens=max_new_tokens,
             temperature=temperature,
             top_p=top_p,
+            top_k=top_k,
+            repetition_penalty=repetition_penalty,
+            no_repeat_ngram_size=no_repeat_ngram_size,
             do_sample=do_sample,
             num_return_sequences=num_return_sequences,
             return_dict_in_generate=True,
@@ -482,11 +529,25 @@ class WisentModel:
             **gen_kwargs,
         )
 
+        # Add diversity processors if requested
+        if ensure_varied_responses and phrase_ledger:
+            from wisent.core.diversity_processors import build_diversity_processors
+            logits_processors = build_diversity_processors(self.tokenizer, phrase_ledger)
+            if logits_processors:
+                generation_kwargs['logits_processor'] = logits_processors
+
+        gen_out = self.hf_model.generate(**generation_kwargs)
+
         if use_steering:
             self.detach()
 
         seqs = gen_out.sequences  # [B * num_return_sequences, T_total]
         texts = self.tokenizer.batch_decode(seqs, skip_special_tokens=True)
+
+        # Extract only assistant responses when using chat templates
+        if not prompt_is_formatted and not isinstance(inputs, str):
+            texts = [self._extract_assistant_response(text) for text in texts]
+
         return texts
 
     @torch.inference_mode()
@@ -496,12 +557,17 @@ class WisentModel:
         max_new_tokens: int = 64,
         temperature: float = 0.7,
         top_p: float = 0.95,
+        top_k: int = 50,
+        repetition_penalty: float = 1.12,
+        no_repeat_ngram_size: int = 4,
         do_sample: bool = True,
         num_return_sequences: int = 1,
         collect_topk: int = 5,
         use_steering: bool = False,
         steering_plan: SteeringPlan | None = None,
         enable_thinking: bool = True,
+        ensure_varied_responses: bool = False,
+        phrase_ledger: Any = None,
         **gen_kwargs: Any,
     ) -> tuple[list[str], list[GenerationStats]]:
         """
@@ -571,11 +637,15 @@ class WisentModel:
 
         batch = self._batch_encode(inputs, add_generation_prompt=True, enable_thinking=enable_thinking)
 
-        out = self.hf_model.generate(
+        # Build generation kwargs
+        generation_kwargs = dict(
             **batch,
             max_new_tokens=max_new_tokens,
             temperature=temperature,
             top_p=top_p,
+            top_k=top_k,
+            repetition_penalty=repetition_penalty,
+            no_repeat_ngram_size=no_repeat_ngram_size,
             do_sample=do_sample,
             num_return_sequences=num_return_sequences,
             return_dict_in_generate=True,
@@ -583,11 +653,23 @@ class WisentModel:
             **gen_kwargs,
         )
 
+        # Add diversity processors if requested
+        if ensure_varied_responses and phrase_ledger:
+            from wisent.core.diversity_processors import build_diversity_processors
+            logits_processors = build_diversity_processors(self.tokenizer, phrase_ledger)
+            if logits_processors:
+                generation_kwargs['logits_processor'] = logits_processors
+
+        out = self.hf_model.generate(**generation_kwargs)
+
         if use_steering:
             self.detach()
 
         texts = self.tokenizer.batch_decode(out.sequences, skip_special_tokens=True)
 
+        # Extract only assistant responses when using chat templates
+        texts = [self._extract_assistant_response(text) for text in texts]
+
         scores: list[torch.Tensor] = list(out.scores or [])
         stats: list[GenerationStats] = []
 
@@ -636,6 +718,9 @@ class WisentModel:
         max_new_tokens: int = 128,
         temperature: float = 0.7,
         top_p: float = 0.95,
+        top_k: int = 50,
+        repetition_penalty: float = 1.12,
+        no_repeat_ngram_size: int = 4,
         do_sample: bool = True,
         use_steering: bool = False,
         steering_plan: SteeringPlan | None = None,
@@ -643,6 +728,8 @@ class WisentModel:
         skip_special_tokens: bool = True,
         enable_thinking: bool = True,
         prompt_is_formatted: bool = False,
+        ensure_varied_responses: bool = False,
+        phrase_ledger: Any = None,
         **gen_kwargs: Any,
     ) -> Iterable[str]:
         """
@@ -717,13 +804,23 @@ class WisentModel:
             max_new_tokens=max_new_tokens,
             temperature=temperature,
             top_p=top_p,
+            top_k=top_k,
+            repetition_penalty=repetition_penalty,
+            no_repeat_ngram_size=no_repeat_ngram_size,
             do_sample=do_sample,
-            return_dict_in_generate=False,   
+            return_dict_in_generate=False,
             output_scores=False,
             streamer=streamer,
             **gen_kwargs,
         )
 
+        # Add diversity processors if requested
+        if ensure_varied_responses and phrase_ledger:
+            from wisent.core.diversity_processors import build_diversity_processors
+            logits_processors = build_diversity_processors(self.tokenizer, phrase_ledger)
+            if logits_processors:
+                generation_kwargs['logits_processor'] = logits_processors
+
         worker = threading.Thread(
             target=self.hf_model.generate,
             kwargs=generation_kwargs,
