@@ -7,8 +7,9 @@ from typing import Any, Dict, List, Optional, Union
 import torch
 import torch.nn.functional as F
 
-from wisent.core.activations import Activations
-from wisent.core.classifier.classifier import Classifier
+# Note: Activations and Classifier imports removed - these classes don't exist in the current package structure
+# from wisent.core.activations import Activations
+# from wisent.core.classifier.classifier import Classifier
 
 from .contrastive_pairs import ContrastivePairSet
 from .steering_method import CAA
